@@ -1,10 +1,7 @@
+def default_cb():
+  return
 
-# import msgpack
-def test():
-  print('Krit naja')
-  print('DONE !!!!!')
-
-def subscribe(option, cb):
+def subscribe(option = {}, cb = default_cb):
   # TODO: validate function callback
   # TODO: handler error
   from kafka import KafkaConsumer
@@ -21,9 +18,9 @@ def subscribe(option, cb):
   resCall = requests.get(api_url + '/call/')
   resMessage = requests.get(api_url + '/message/')
 
-  cb('internet_init', resInternet.json())
-  cb('call_init', resCall.json())
-  cb('message_init', resMessage.json())
+  cb('internet', resInternet.json())
+  cb('call', resCall.json())
+  cb('message', resMessage.json())
 
   consumer = KafkaConsumer(
     bootstrap_servers=kafka_url,
@@ -36,6 +33,6 @@ def subscribe(option, cb):
     print(msg)
     print(msg.value)
     print(msg.value.decode('utf-8'))
-    cb('something_increase', msg.value.decode('utf-8'))
+    cb('something_increase', [msg.value.decode('utf-8')])
     print('===============')
     # assert isinstance(msg.value, dict)
\ No newline at end of file
